WxDataViewRenderer class

Base class for all renderers used for WxDataViewCtrl.

A derived renderer usually has to override render and sometimes getSize and sometimes activateCell in order to react to a double click or pressing <ENTER>.

Provides the convenience function renderText that clips text to fit into a column using an ellipsis.

Cell mode constants

constant meaning
wxDATAVIEW_CELL_INERT not editing possible
wxDATAVIEW_CELL_ACTIVATABLE can react to mouse click on <ENTER>
wxDATAVIEW_CELL_EDITABLE can be editted in-place

Cell state constants

constant meaning
wxDATAVIEW_CELL_SELECTED cell or row is currently selected
wxDATAVIEW_CELL_PRELIT mouse is over cell or row
wxDATAVIEW_CELL_INSENSITIVE cell should show disabled state
wxDATAVIEW_CELL_FOCUSED cell or control has focus
Inheritance
Implementers

Constructors

WxDataViewRenderer(String variantType, {int mode = wxDATAVIEW_CELL_INERT, int alignment = wxDVR_DEFAULT_ALIGNMENT})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateCell(WxRect cell, WxDataViewModel model, WxDataViewItem item, int col, {bool fromMouseClick = false, WxPoint pos = wxDefaultPosition}) bool
cancelEditing() → void
checkedGetValue(WxDataViewModel model, WxDataViewItem item, int column) → dynamic
createEditorCtrl(WxWindow parent, WxRect labelRect, dynamic value) WxWindow?
disableEllipsize() → void
dispose() → void
Destroys the C++ wxObject instance in wxDart Native
inherited
enableEllipsize({int mode = wxELLIPSIZE_MIDDLE}) → void
finishEditing() bool
getAlignment() int
getAttr() WxDataViewItemAttr?
getEditorCtrl() WxWindow?
getEllipsizeMode() int
getEnabled() bool
getInfoDC() WxInfoDC?
getMode() int
getOwner() WxDataViewColumn
getSize() WxSize
getValue() → dynamic
getValueFromEditorCtrl(WxWindow editor) → dynamic
getVariantType() String
hasEditorCtrl() bool
isCompatibleVariantType(String variantType) bool
isCustomRenderer() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareForItem(WxDataViewModel model, WxDataViewItem item) bool
printName() → void
Prints the name of the Dart class in wxDart Flutter and the name of the C++ class in wxDart Native
inherited
render(WxRect cell, WxDC dc, int state) bool
renderBackground(WxDC dc, WxRect rect) → void
renderText(String text, int xoffset, WxRect rect, WxDC dc, int state) → void
setAlignment(int alignment) → void
setEnabled(bool enabled) → void
setMode(int mode) → void
setOwner(WxDataViewColumn owner) → void
setValue(dynamic value) → void
setVariantType(String variantType) → void
startEditing(WxDataViewItem item, WxRect labelRect) bool
toString() String
A string representation of this object.
inherited
validate(dynamic value) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited