WxDataViewTreeStore class

Specialized WxDataViewModel that actually stores data for a tree like model.

Used internally by WxDataViewTreeCtrl.

Inheritance
Implementers

Constructors

WxDataViewTreeStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addNotifier(WxDataViewModelNotifier notifier) → void
Adds a notifier to the model
inherited
appendItem(WxDataViewItem parent, WxBitmap? icon, String text, {dynamic data}) WxDataViewItem
changeValue(dynamic value, WxDataViewItem item, int column) bool
Change the value of the given item and update the control to reflect it
inherited
cleared() bool
Called to inform the model that all of its data has been changed.
inherited
compare(WxDataViewItem item1, WxDataViewItem item2, int column, bool ascending) int
Compare the two items
inherited
deleteAllItems() → void
deleteItem(WxDataViewItem item) → void
getAttr(WxDataViewItem item, int col) WxDataViewItemAttr?
Override to give a WxDataViewItemAttr to a specific item or return null for default font attributes
override
getChildren(WxDataViewItem item) List<WxDataViewItem>
Override this so the control can query the child items of item.
override
getItemData(WxDataViewItem item) → dynamic
getItemText(WxDataViewItem item) String
getParent(WxDataViewItem item) WxDataViewItem
Override this to indicate which WxDataViewItem representing the parent of item or an invalid WxDataViewItem if the root item is the parent item.
override
getValue(WxDataViewItem item, int column) → dynamic
Override this to return the value to be shown for the specified item in the given column. The value returned must have the appropriate type, e.g. String for the text columns.
override
hasContainerColumns(WxDataViewItem item) bool
Override this method to indicate if a container item merely acts as a headline
inherited
hasDefaultCompare() bool
Returns true of model uses the defaul compare method
inherited
hasValue(WxDataViewItem item, int column) bool
Returns true if specified field (item and colunmn) contains data
inherited
isContainer(WxDataViewItem item) bool
Override this to indicate if item is a container, i.e. if it can have child items.
override
isEnabled(WxDataViewItem item, int column) bool
Override to return false if an item is disabled
inherited
isListModel() bool
override in case class if this is a index based list model
inherited
isVirtualListModel() bool
override in case class if this is a index based virtual list model
inherited
itemAdded(WxDataViewItem parent, WxDataViewItem item) bool
Inform all notifiers that an item has been added to the model and allow an the associated WxDataViewCtrl to update the display
inherited
itemChanged(WxDataViewItem item) bool
Inform all notifiers that an item has been changed and allow an the associated WxDataViewCtrl to update the display
inherited
itemDeleted(WxDataViewItem parent, WxDataViewItem item) bool
Inform all notifiers that an item has been deleted and allow an the associated WxDataViewCtrl to update the display
inherited
itemsAdded(WxDataViewItem parent, List<WxDataViewItem> items) bool
Inform all notifiers that items have been added to the model and allow an the associated WxDataViewCtrl to update the display
inherited
itemsChanged(List<WxDataViewItem> items) bool
Inform all notifiers that items have been changed and allow an the associated WxDataViewCtrl to update the display
inherited
itemsDeleted(WxDataViewItem parent, List<WxDataViewItem> items) bool
Inform all notifiers that an items have been deleted and allow an the associated WxDataViewCtrl to update the display
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeNotifier(WxDataViewModelNotifier notifier) → void
Removes the notifier from the model
inherited
resort() → void
Resorts data (TBD)
inherited
setItemData(WxDataViewItem item, dynamic data) → void
setItemText(WxDataViewItem item, String text) → void
setValue(dynamic value, WxDataViewItem item, int column) bool
Called by the WxDataViewCtrl or your own code to commit new data to the model
inherited
toString() String
A string representation of this object.
inherited
valueChanged(WxDataViewItem item, int column) bool
Inform all notifiers that the value of an item has been changed and allow an the associated WxDataViewCtrl to update the display
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited