getValue method
Override this to return the value to be shown for the specified item in the given column. The value
returned must have the appropriate type, e.g. String for the text columns.
May return null indicating that there is not data.
Implementation
@override
dynamic getValue( WxDataViewItem item, int column )
{
if (!item.isOk()) return null;
WxDataViewTreeStoreNode node = item.getID();
return node._data;
}