destroy method
Delete this window and remove it from the parent's child window list
Implementation
bool destroy() {
if (_parent != null) {
_parent!.removeChild(this);
}
dispose();
return true;
}
Delete this window and remove it from the parent's child window list
bool destroy() {
if (_parent != null) {
_parent!.removeChild(this);
}
dispose();
return true;
}