layout method
void
layout()
If any WxSizer has been associated with this window, perform a layout.
The window or dialog will perform a layout when initially shown, but when something changes after the window was shown, then you need to call layout in wxDart Native. In wxDart Flutter, the window layout will get updated automatically and this function will not do anything.
Implementation
void layout() {
// do nothing
}