refresh method

void refresh()

Refreshes window. If a batch of updates is happening, you may want to freeze and then thaw the window.

see freeze and thaw

Implementation

void refresh() {
  _setState();
}