setFont method
Sets the font of the window. This can have different effects in different controls. Be careful with different default font sizes on different platforms.
Implementation
void setFont( WxFont? font ) {
_font = font;
_setState();
}
Sets the font of the window. This can have different effects in different controls. Be careful with different default font sizes on different platforms.
void setFont( WxFont? font ) {
_font = font;
_setState();
}