WxSysColourChangedEvent class
| SysColourChanged event gets sent when themes or light/dark modes have changed. |
| void bindSysColourChangedEvent( OnSysColourChangedEventFunc ) |
| void unbindSysColourChangedEvent() |
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose()
→ void
-
Destroys the C++ wxObject instance in wxDart Native
inherited
-
getEventObject()
→ WxObject?
-
Gets the object from which the event originates
inherited
-
getEventType()
→ int
-
inherited
-
getId()
→ int
-
inherited
-
getSkipped()
→ bool
-
True if event should be handled as not yet handled
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
printName()
→ void
-
Prints the name of the Dart class in wxDart Flutter and the
name of the C++ class in wxDart Native
inherited
-
setEventObject(WxObject object)
→ void
-
Sets the object from which the event originates
inherited
-
setEventType(int type)
→ void
-
inherited
-
setId(int id)
→ void
-
inherited
-
skip({bool skip = true})
→ void
-
Marks the event as unread so that other event handler can
handle this event again
inherited
-
toString()
→ String
-
A string representation of this object.
inherited